==> constellationdaq-0.1.tar.gz: constellationdaq-0.1/README.md <==
<!--
SPDX-FileCopyrightText: 2023 DESY and the Constellation authors
SPDX-License-Identifier: CC-BY-4.0
-->
<!-- markdownlint-disable-next-line first-line-heading -->
[![Logo](docs/logo/logo_small.png)](https://constellation.pages.desy.de/)

# Constellation

## The Autonomous Control and Data Acquisition System for Dynamic Experimental Setups

Constellation is a control and data acquisition system for small-scale experiments and experimental setup with volatile and dynamic constituents such as testbeam environments or laboratory test stands. Constellation aims to provide a flexible SCADA software system that requires minimal effort for the integration of new devices, that is based on widely adopted open-source network communication libraries and that keeps the required maintenance as low as possible.

More details about the project can be found on the website at [constellation.pages.desy.de](https://constellation.pages.desy.de/).

[![Latest Release](https://gitlab.desy.de/constellation/constellation/-/badges/release.svg)](https://gitlab.desy.de/constellation/constellation/-/releases)
[![License: EUPL 1.2](https://img.shields.io/badge/License-EUPL%201.2-blue.svg)](https://opensource.org/license/eupl-1-2/)
[![REUSE Status](https://api.reuse.software/badge/gitlab.desy.de/constellation/constellation)](https://api.reuse.software/info/gitlab.desy.de/constellation/constellation)
[![Coverage Report](https://gitlab.desy.de/constellation/constellation/badges/main/coverage.svg)](https://gitlab.desy.de/constellation/constellation/-/graphs/main/charts)
[![Build Status](https://gitlab.desy.de/constellation/constellation/badges/main/pipeline.svg)](https://gitlab.desy.de/constellation/constellation/-/commits/main)

## Licenses

This software is distributed under the terms of the EUPL-1.2 license. The documentation is distributed under the terms of the CC-BY-4.0 license.

This repository follows the [REUSE](https://reuse.software/) specification, a full copyright report can be created via `reuse spdx`.

A copy of all licenses can be found in the [LICENSES](LICENSES/) folder.

==> constellationdaq-0.3.tar.gz: constellationdaq-0.3/README.md <==
<!--
SPDX-FileCopyrightText: 2023 DESY and the Constellation authors
SPDX-License-Identifier: CC-BY-4.0
-->
<!-- markdownlint-disable-next-line first-line-heading -->
[![Logo](docs/logo/logo_small.png)](https://constellation.pages.desy.de/)

# Constellation

## The Autonomous Control and Data Acquisition System for Dynamic Experimental Setups

Constellation is an autonomous control and data acquisition system for small-scale experiments and experimental setup with volatile and dynamic constituents such as testbeam environments or laboratory test stands. Constellation aims to provide a flexible framework that requires minimal effort for the integration of new devices, that is based on widely adopted open-source network communication libraries and that keeps the required maintenance as low as possible.

More details about the project can be found on the website at [constellation.pages.desy.de](https://constellation.pages.desy.de/).

[![Latest Release](https://gitlab.desy.de/constellation/constellation/-/badges/release.svg)](https://gitlab.desy.de/constellation/constellation/-/releases)
[![License: EUPL 1.2](https://img.shields.io/badge/License-EUPL%201.2-blue.svg)](https://opensource.org/license/eupl-1-2/)
[![REUSE Status](https://api.reuse.software/badge/gitlab.desy.de/constellation/constellation)](https://api.reuse.software/info/gitlab.desy.de/constellation/constellation)
[![Coverage Report](https://gitlab.desy.de/constellation/constellation/badges/main/coverage.svg)](https://gitlab.desy.de/constellation/constellation/-/graphs/main/charts)
[![Build Status](https://gitlab.desy.de/constellation/constellation/badges/main/pipeline.svg)](https://gitlab.desy.de/constellation/constellation/-/commits/main)

## Licenses

This software is distributed under the terms of the EUPL-1.2 license. The documentation is distributed under the terms of the CC-BY-4.0 license.

This repository follows the [REUSE](https://reuse.software/) specification, a full copyright report can be created via `reuse spdx`.

A copy of all licenses can be found in the [LICENSES](LICENSES/) folder.
